# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.landing_get import LandingGet  # noqa: E501

class TestLandingGet(unittest.TestCase):
    """LandingGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LandingGet:
        """Test LandingGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LandingGet`
        """
        model = LandingGet()  # noqa: E501
        if include_optional:
            return LandingGet(
                html = '',
                css = '',
                js = '',
                components = landing_page_server_connector.models.components.Components(),
                styles = [
                    None
                    ],
                assets = [
                    None
                    ],
                theme = landing_page_server_connector.models.theme.Theme(),
                name = '',
                title = '',
                path = '',
                order = 56,
                editor_version = 1,
                portal_id = 56,
                id = 56,
                uuid = '',
                preview_id = '',
                google_analytics_pixel = '',
                google_tag_manager_pixel = '',
                facebook_pixel = '',
                tiktok_pixel = '',
                pinterest_pixel = '',
                custom_scripts = [
                    landing_page_server_connector.models.landing_script_get.LandingScriptGet(
                        elements = [
                            landing_page_server_connector.models.script_element.ScriptElement(
                                tag = '', 
                                content = '', 
                                src = '', 
                                href = '', 
                                rel = '', )
                            ], 
                        title = '', 
                        category = 'analytics', 
                        placement = 'body', 
                        elements_str = '', )
                    ],
                requires_correction = True,
                created_at = 56,
                updated_at = 56,
                published_at = 56
            )
        else:
            return LandingGet(
                html = '',
                css = '',
                js = '',
                components = landing_page_server_connector.models.components.Components(),
                styles = [
                    None
                    ],
                assets = [
                    None
                    ],
                name = '',
                title = '',
                path = '',
                order = 56,
                portal_id = 56,
                id = 56,
                uuid = '',
                custom_scripts = [
                    landing_page_server_connector.models.landing_script_get.LandingScriptGet(
                        elements = [
                            landing_page_server_connector.models.script_element.ScriptElement(
                                tag = '', 
                                content = '', 
                                src = '', 
                                href = '', 
                                rel = '', )
                            ], 
                        title = '', 
                        category = 'analytics', 
                        placement = 'body', 
                        elements_str = '', )
                    ],
                requires_correction = True,
                created_at = 56,
        )
        """

    def testLandingGet(self):
        """Test LandingGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.response_wrapper_list_landing_list_get import ResponseWrapperListLandingListGet  # noqa: E501

class TestResponseWrapperListLandingListGet(unittest.TestCase):
    """ResponseWrapperListLandingListGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListLandingListGet:
        """Test ResponseWrapperListLandingListGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListLandingListGet`
        """
        model = ResponseWrapperListLandingListGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperListLandingListGet(
                done = True,
                result = [
                    landing_page_server_connector.models.landing_list_get.LandingListGet(
                        id = 56, 
                        portal_id = 56, 
                        order = 56, 
                        uuid = '', 
                        editor_version = 1, 
                        name = '', 
                        title = '', 
                        path = '', 
                        preview_id = '', 
                        requires_correction = True, 
                        created_at = 56, 
                        updated_at = 56, 
                        published_at = 56, )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListLandingListGet(
                done = True,
        )
        """

    def testResponseWrapperListLandingListGet(self):
        """Test ResponseWrapperListLandingListGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
